@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package YAML::PP::Dumper;
 
-our $VERSION = '0.022_001'; # TRIAL VERSION
+our $VERSION = '0.022_002'; # TRIAL VERSION
 
 use Scalar::Util qw/ blessed refaddr reftype /;
 use YAML::PP;
@@ -219,6 +219,7 @@ my %_reftypes = (
     CODE => 1,
     SCALAR => 1,
     REF => 1,
+    GLOB => 1,
 );
 
 sub check_references {
@@ -226,6 +227,13 @@ sub check_references {
     my $reftype = reftype $doc or return;
     my $seen = $self->{seen};
     # check which references are used more than once
+    if ($reftype eq 'SCALAR' and ref $doc eq $self->representer->schema->bool_class) {
+        # JSON::PP and boolean.pm always return the same reference for booleans
+        # Avoid printing *aliases in those case
+        if (ref $doc eq 'boolean' or ref $doc eq 'JSON::PP::Boolean') {
+            return;
+        }
+    }
     if (++$seen->{ refaddr $doc } > 1) {
         # seen already
         return;
