@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package YAML::PP::Representer;
 
-our $VERSION = '0.022_001'; # TRIAL VERSION
+our $VERSION = '0.022_002'; # TRIAL VERSION
 
 use Scalar::Util qw/ reftype blessed refaddr /;
 
@@ -60,8 +60,11 @@ sub represent_node {
         }
     }
     $node->{reftype} = reftype($node->{value});
+    if (not $node->{reftype} and reftype(\$node->{value}) eq 'GLOB') {
+        $node->{reftype} = 'GLOB';
+    }
 
-    if (ref $node->{value}) {
+    if ($node->{reftype}) {
         $self->represent_noderef($node);
     }
     else {
@@ -185,6 +188,10 @@ sub represent_noderef {
         my $code = $coderef->{code};
         return 1 if $code->($self, $node);
     }
+    if ($node->{reftype} eq 'GLOB' and my $glob = $representers->{glob}) {
+        my $code = $glob->{code};
+        return 1 if $code->($self, $node);
+    }
     $node->{data} = $node->{value};
 
 }
