@@ -4,7 +4,7 @@ package YAML::PP::Schema;
 use B;
 use Module::Load qw//;
 
-our $VERSION = '0.022_001'; # TRIAL VERSION
+our $VERSION = '0.022_002'; # TRIAL VERSION
 
 use YAML::PP::Common qw/ YAML_PLAIN_SCALAR_STYLE /;
 
@@ -53,6 +53,7 @@ sub new {
         scalarref => undef,
         refref => undef,
         coderef => undef,
+        glob => undef,
         tied_equals => {},
     );
     my $self = bless {
@@ -269,6 +270,12 @@ sub add_representer {
         };
         return;
     }
+    if (defined(my $glob = $args{glob})) {
+        $representers->{glob} = {
+            code => $args{code},
+        };
+        return;
+    }
     if (my $undef = $args{undefined}) {
         $representers->{undef} = $undef;
         return;
